Groups | Search | Server Info | Keyboard shortcuts | Login | Register [http] [https] [nntp] [nntps]


Groups > linux.debian.user > #206296 > unrolled thread

youtube video downloader for chrome

Started byPierre Frenkiel <pierre.frenkiel@gmail.com>
First post2019-03-18 11:10 +0100
Last post2019-03-24 12:20 +0100
Articles 20 on this page of 29 — 10 participants

Back to article view | Back to linux.debian.user


Contents

  youtube video downloader for chrome Pierre Frenkiel <pierre.frenkiel@gmail.com> - 2019-03-18 11:10 +0100
    Re: youtube video downloader for chrome David <bouncingcats@gmail.com> - 2019-03-18 12:30 +0100
      Re: youtube video downloader for chrome Pierre Frenkiel <pierre.frenkiel@gmail.com> - 2019-03-18 12:40 +0100
        Re: youtube video downloader for chrome Carl Fink <carl@finknetwork.com> - 2019-03-18 14:50 +0100
          Re: youtube video downloader for chrome riveravaldez <riveravaldezmail@gmail.com> - 2019-03-20 00:00 +0100
            Re: youtube video downloader for chrome Pierre Frenkiel <pierre.frenkiel@gmail.com> - 2019-03-20 10:40 +0100
              Re: youtube video downloader for chrome Brad Rogers <brad@fineby.me.uk> - 2019-03-20 11:30 +0100
              Re: youtube video downloader for chrome Greg Wooledge <wooledg@eeg.ccf.org> - 2019-03-20 13:10 +0100
                Re: youtube video downloader for chrome David Wright <deblis@lionunicorn.co.uk> - 2019-03-20 19:20 +0100
                  Re: youtube video downloader for chrome rhkramer@gmail.com - 2019-03-20 20:10 +0100
                    Re: youtube video downloader for chrome Celejar <celejar@gmail.com> - 2019-03-20 23:30 +0100
                      Re: youtube video downloader for chrome David Wright <deblis@lionunicorn.co.uk> - 2019-03-23 02:00 +0100
                        Re: youtube video downloader for chrome Celejar <celejar@gmail.com> - 2019-03-25 03:20 +0100
                    Re: youtube video downloader for chrome David Wright <deblis@lionunicorn.co.uk> - 2019-03-21 01:30 +0100
                      Re: youtube video downloader for chrome rhkramer@gmail.com - 2019-03-21 03:20 +0100
                Re: youtube video downloader for chrome Pierre Frenkiel <pierre.frenkiel@gmail.com> - 2019-03-20 19:20 +0100
              Re: youtube video downloader for chrome Celejar <celejar@gmail.com> - 2019-03-20 23:20 +0100
                Re: youtube video downloader for chrome Pierre Frenkiel <pierre.frenkiel@gmail.com> - 2019-03-21 15:40 +0100
                  Re: youtube video downloader for chrome David Wright <deblis@lionunicorn.co.uk> - 2019-03-21 16:50 +0100
                    Re: youtube video downloader for chrome Fred <fred@blakemfg.com> - 2019-03-21 18:40 +0100
                      Re: youtube video downloader for chrome Pierre Frenkiel <pierre.frenkiel@gmail.com> - 2019-03-21 20:00 +0100
                      Re: youtube video downloader for chrome David Wright <deblis@lionunicorn.co.uk> - 2019-03-21 20:00 +0100
                        Re: youtube video downloader for chrome Fred <fred@blakemfg.com> - 2019-03-21 22:50 +0100
                          Re: youtube video downloader for chrome Greg Wooledge <wooledg@eeg.ccf.org> - 2019-03-22 13:10 +0100
                            Re: youtube video downloader for chrome Fred <fred@blakemfg.com> - 2019-03-22 15:20 +0100
                          Re: youtube video downloader for chrome David Wright <deblis@lionunicorn.co.uk> - 2019-03-23 02:10 +0100
                            Re: youtube video downloader for chrome Pierre Frenkiel <pierre.frenkiel@gmail.com> - 2019-03-23 20:20 +0100
                              Re: youtube video downloader for chrome David Wright <deblis@lionunicorn.co.uk> - 2019-03-24 17:10 +0100
                Re: youtube video downloader for chrome Pierre Frenkiel <pierre.frenkiel@gmail.com> - 2019-03-24 12:20 +0100

Page 1 of 2  [1] 2  Next page →


#206296 — youtube video downloader for chrome

FromPierre Frenkiel <pierre.frenkiel@gmail.com>
Date2019-03-18 11:10 +0100
Subjectyoutube video downloader for chrome
Message-ID<xCXnr-9M-7@gated-at.bofh.it>
hi,
I'm trying to install a youtube video downloader extension to google-chrome,
but nothing works. 
Googling led me to the google web store, but
no such extension is available there.
For the only one I found elsewhere, I got "manifest.json is missing"
Any idea?

best regards,
-- 
Pierre Frenkiel

[toc] | [next] | [standalone]


#206298

FromDavid <bouncingcats@gmail.com>
Date2019-03-18 12:30 +0100
Message-ID<xCYCT-R3-23@gated-at.bofh.it>
In reply to#206296
On Mon, 18 Mar 2019 at 21:08, Pierre Frenkiel <pierre.frenkiel@gmail.com> wrote:
>
> I'm trying to install a youtube video downloader extension to google-chrome,
> but nothing works.

youtube is a subsidiary company of google, which also makes chrome.

You could try this instead:
https://packages.debian.org/stretch/youtube-dl

[toc] | [prev] | [next] | [standalone]


#206299

FromPierre Frenkiel <pierre.frenkiel@gmail.com>
Date2019-03-18 12:40 +0100
Message-ID<xCYMy-Ua-5@gated-at.bofh.it>
In reply to#206298
On Mon, 18 Mar 2019, David wrote:

> On Mon, 18 Mar 2019 at 21:08, Pierre Frenkiel <pierre.frenkiel@gmail.com> wrote:
>>
>> I'm trying to install a youtube video downloader extension to google-chrome,
>> but nothing works.
>
> youtube is a subsidiary company of google, which also makes chrome.
>
> You could try this instead:
> https://packages.debian.org/stretch/youtube-dl
>


   thank you David for your suggestion. It's exactly what I was doing but
I don't understand why the gui version works perfectly on my intel desktop
(i.e. I have the youtube video downloader button in my toolbar), and can't
be installed on amd64.

best regards,
-- 
Pierre Frenkiel

[toc] | [prev] | [next] | [standalone]


#206308

FromCarl Fink <carl@finknetwork.com>
Date2019-03-18 14:50 +0100
Message-ID<xD0Om-25A-27@gated-at.bofh.it>
In reply to#206299
On Mon, Mar 18, 2019 at 12:36:37PM +0100, Pierre Frenkiel wrote:

>   thank you David for your suggestion. It's exactly what I was doing but
> I don't understand why the gui version works perfectly on my intel desktop
> (i.e. I have the youtube video downloader button in my toolbar), and can't
> be installed on amd64.

I don't know the extension you're using is having trouble, but the
VideoDownloadHelper extension needs a companion app to download most video
these days. Maybe your extension only has a companion app compiled for
Intel?
-- 
Carl Fink                           nitpicking@nitpicking.com 

Read John Grant's book, Corrupted Science: http://a.co/9UsUoGu 
Dedicated to ... Carl Fink!

[toc] | [prev] | [next] | [standalone]


#206379

Fromriveravaldez <riveravaldezmail@gmail.com>
Date2019-03-20 00:00 +0100
Message-ID<xDvSa-50u-1@gated-at.bofh.it>
In reply to#206308
On 3/18/19, Carl Fink <carl@finknetwork.com> wrote:
> On Mon, Mar 18, 2019 at 12:36:37PM +0100, Pierre Frenkiel wrote:
>
>>   thank you David for your suggestion. It's exactly what I was doing but
>> I don't understand why the gui version works perfectly on my intel
>> desktop
>> (i.e. I have the youtube video downloader button in my toolbar), and
>> can't
>> be installed on amd64.
>
> I don't know the extension you're using is having trouble, but the
> VideoDownloadHelper extension needs a companion app to download most video
> these days. Maybe your extension only has a companion app compiled for
> Intel?
> --
> Carl Fink                           nitpicking@nitpicking.com

Maybe worth mentioning: youtube-dl, exceptionally useful and simple CLI tool.

Available on official repositories.

[toc] | [prev] | [next] | [standalone]


#206387

FromPierre Frenkiel <pierre.frenkiel@gmail.com>
Date2019-03-20 10:40 +0100
Message-ID<xDFRw-30F-7@gated-at.bofh.it>
In reply to#206379
On Tue, 19 Mar 2019, riveravaldez wrote:

> Maybe worth mentioning: youtube-dl, exceptionally useful and simple CLI tool.

   useful and simple... but it works only for urls with alphanumeric characters
   I tried with an url containing ? and &, and I got nothing
   I tried also by escaping ? and & with \, and it was not better.
   I'll send you an example later, if you are not convinced...

best regards,
-- 
Pierre Frenkiel

[toc] | [prev] | [next] | [standalone]


#206389

FromBrad Rogers <brad@fineby.me.uk>
Date2019-03-20 11:30 +0100
Message-ID<xDGDT-3xo-1@gated-at.bofh.it>
In reply to#206387

[Multipart message — attachments visible in raw view] — view raw

On Wed, 20 Mar 2019 10:34:42 +0100 (CET)
Pierre Frenkiel <pierre.frenkiel@gmail.com> wrote:

Hello Pierre,

> I tried also by escaping ? and & with \, and it was not better.

I wouldn't expect it to be.  It's more usual to replace each such
character with its HEX counterpart, thus;

  ? converts to %3F
  & converts to %26

-- 
 Regards  _
         / )           "The blindingly obvious is
        / _)rad        never immediately apparent"
They said we'd be artistically free, but that was on a bit of paper
Complete Control - The Clash

[toc] | [prev] | [next] | [standalone]


#206392

FromGreg Wooledge <wooledg@eeg.ccf.org>
Date2019-03-20 13:10 +0100
Message-ID<xDIcG-4C8-21@gated-at.bofh.it>
In reply to#206387
On Wed, Mar 20, 2019 at 10:34:42AM +0100, Pierre Frenkiel wrote:
> On Tue, 19 Mar 2019, riveravaldez wrote:
> 
> > Maybe worth mentioning: youtube-dl, exceptionally useful and simple CLI tool.
> 
>   useful and simple... but it works only for urls with alphanumeric characters
>   I tried with an url containing ? and &, and I got nothing

You probably forgot to quote the URL in your shell command.  If you don't
quote it, the & is special to the shell and will cause the command to
be split at that point, with the first half being run as a background
command, and the second half being run as a foreground command.

>   I tried also by escaping ? and & with \, and it was not better.
>   I'll send you an example later, if you are not convinced...

That should work.  An example of the failure would be helpful.

Generally speaking, though, just wrap the whole URL in single quotes
and you should be fine.

[toc] | [prev] | [next] | [standalone]


#206400

FromDavid Wright <deblis@lionunicorn.co.uk>
Date2019-03-20 19:20 +0100
Message-ID<xDNYJ-8eO-9@gated-at.bofh.it>
In reply to#206392
On Wed 20 Mar 2019 at 08:08:56 (-0400), Greg Wooledge wrote:
> On Wed, Mar 20, 2019 at 10:34:42AM +0100, Pierre Frenkiel wrote:
> > On Tue, 19 Mar 2019, riveravaldez wrote:
> > 
> > > Maybe worth mentioning: youtube-dl, exceptionally useful and simple CLI tool.
> > 
> >   useful and simple... but it works only for urls with alphanumeric characters
> >   I tried with an url containing ? and &, and I got nothing
> 
> You probably forgot to quote the URL in your shell command.  If you don't
> quote it, the & is special to the shell and will cause the command to
> be split at that point, with the first half being run as a background
> command, and the second half being run as a foreground command.
> 
> >   I tried also by escaping ? and & with \, and it was not better.
> >   I'll send you an example later, if you are not convinced...
> 
> That should work.  An example of the failure would be helpful.
> 
> Generally speaking, though, just wrap the whole URL in single quotes
> and you should be fine.

This is a trick I find very useful too: RightClick on a google hit,
type a, then paste the address into this function on an xterm:

function gy-in-quotes {
    [ -z "$1" ] && printf '%s\n' "Usage:	$FUNCNAME 'URL' (must be in single quotes!)
	strips the google prefix (up to url=) and suffix (from &usg=) from the argument,
	translates various common %nn sequences in the URL, and retrieves it." >&2 && return 1
    youtube-dl $(sed -e 's/http.*url=//;s/&usg=.*$//;s/%2F/\//g;s/%3A/:/g;s/%3D/=/g;s/%3F/?/g;s/%25/%/g' <<<"$1") # % characters must be edited last
}

The same idea works of course for wget:

function wg-in-quotes {
    [ -z "$1" ] && printf '%s\n' "Usage:	$FUNCNAME 'URL' (must be in single quotes!)
	strips the google prefix (up to url=) and suffix (from &usg=) from the argument,
	translates various common %nn sequences in the URL, and retrieves it." >&2 && return 1
    wget $(sed -e 's/http.*url=//;s/&usg=.*$//;s/%2F/\//g;s/%3A/:/g;s/%3D/=/g;s/%3F/?/g;s/%25/%/g' <<<"$1") # % characters must be edited last
}

Of course, I only type gy-<TAB> or wg-<TAB>, but the function name
reminds me to add the quotes, else all hell breaks loose.

Actually I don't call youtube-dl as above, because I have two helper
functions which do things like history logging to prevent me
accidentally downloading the same video twice.

Cheers,
David.

[toc] | [prev] | [next] | [standalone]


#206404

Fromrhkramer@gmail.com
Date2019-03-20 20:10 +0100
Message-ID<xDOL8-kk-7@gated-at.bofh.it>
In reply to#206400
On Wednesday, March 20, 2019 02:10:57 PM David Wright wrote:
> Actually I don't call youtube-dl as above, because I have two helper
> functions which do things like history logging to prevent me
> accidentally downloading the same video twice.

Are you willing to share?

[toc] | [prev] | [next] | [standalone]


#206413

FromCelejar <celejar@gmail.com>
Date2019-03-20 23:30 +0100
Message-ID<xDRSF-2es-5@gated-at.bofh.it>
In reply to#206404
On Wed, 20 Mar 2019 15:00:12 -0400
rhkramer@gmail.com wrote:

> On Wednesday, March 20, 2019 02:10:57 PM David Wright wrote:
> > Actually I don't call youtube-dl as above, because I have two helper
> > functions which do things like history logging to prevent me
> > accidentally downloading the same video twice.
> 
> Are you willing to share?

Note that you can apparently do something like this natively with
youtube-dl itself - see its --download-archive option.

Celejar

[toc] | [prev] | [next] | [standalone]


#206501

FromDavid Wright <deblis@lionunicorn.co.uk>
Date2019-03-23 02:00 +0100
Message-ID<xEDaV-5Sh-3@gated-at.bofh.it>
In reply to#206413
On Wed 20 Mar 2019 at 18:21:20 (-0400), Celejar wrote:
> On Wed, 20 Mar 2019 15:00:12 -0400 rhkramer@gmail.com wrote:
> > On Wednesday, March 20, 2019 02:10:57 PM David Wright wrote:
> > > Actually I don't call youtube-dl as above, because I have two helper
> > > functions which do things like history logging to prevent me
> > > accidentally downloading the same video twice.
> > 
> > Are you willing to share?
> 
> Note that you can apparently do something like this natively with
> youtube-dl itself - see its --download-archive option.

Sure, but I prefer my history file which saves a valid URL that
I can pass on to people who don't use youtube-dl.

Cheers,
David.

[toc] | [prev] | [next] | [standalone]


#206559

FromCelejar <celejar@gmail.com>
Date2019-03-25 03:20 +0100
Message-ID<xFnnr-Iq-5@gated-at.bofh.it>
In reply to#206501
On Fri, 22 Mar 2019 19:53:10 -0500
David Wright <deblis@lionunicorn.co.uk> wrote:

> On Wed 20 Mar 2019 at 18:21:20 (-0400), Celejar wrote:
> > On Wed, 20 Mar 2019 15:00:12 -0400 rhkramer@gmail.com wrote:
> > > On Wednesday, March 20, 2019 02:10:57 PM David Wright wrote:
> > > > Actually I don't call youtube-dl as above, because I have two helper
> > > > functions which do things like history logging to prevent me
> > > > accidentally downloading the same video twice.
> > > 
> > > Are you willing to share?
> > 
> > Note that you can apparently do something like this natively with
> > youtube-dl itself - see its --download-archive option.
> 
> Sure, but I prefer my history file which saves a valid URL that
> I can pass on to people who don't use youtube-dl.

Gotcha - but your message mentioned specifically prevention of the
accidental download of the same video twice, which my suggestion
accomplishes.

Celejar

[toc] | [prev] | [next] | [standalone]


#206415

FromDavid Wright <deblis@lionunicorn.co.uk>
Date2019-03-21 01:30 +0100
Message-ID<xDTKN-3oE-3@gated-at.bofh.it>
In reply to#206404
On Wed 20 Mar 2019 at 15:00:12 (-0400), rhkramer@gmail.com wrote:
> On Wednesday, March 20, 2019 02:10:57 PM David Wright wrote:
> > Actually I don't call youtube-dl as above, because I have two helper
> > functions which do things like history logging to prevent me
> > accidentally downloading the same video twice.
> 
> Are you willing to share?

Sure. geto(thers) is what gy-in-quotes calls:

function geto {
    local History="$HOME/.get-youtube-download-history"
    local Youtube="$HOME/Youtube"
    [ -z "$1" ] && printf '%s\n' "Usage: $FUNCNAME [-e] [--force] [-s] http...
	gets the specified video into $Youtube.
	If the file already exists (any .ext), it just continues.
	-e just echoes the command that would be used for downloading.
	--force overrides the check that prevents redownloading a file.
	Downloads are logged in $History" >&2 && return 1
    [ ! -r "$History" ] && printf '%s\n' "$History not found!" >&2 && return 1
    [ ! -d "$Youtube" ] && printf '%s\n' "Destination directory $Youtube not found!" >&2 && return 1
    local Echoonly="" Forcing="" Theurl=""
    while [ $# -gt 0 ] ; do
	case "$1" in
	    -e)
		Echoonly=echo
		;;
	    --force)
		Forcing=force
		;;
	    *)
		[ -n "$Theurl" ] && printf '%s\n' "Too many operands" && return 1
		Theurl="$1"
		;;
	esac
	shift
    done
    [ -z "$Theurl" ] && printf '%s\n' "Missing operand" && return 1
    grep -q -e "$Theurl" "$History"
    [ $? -eq 0 -a -z "$Forcing" ] && printf '%s\n' "$Theurl already in download history - override with --force" && return 1
    printf '%s\n' "youtube-dl $Theurl"
    [ -n "$Echoonly" ] && return 0
    ( cd "$Youtube" && youtube-dl -k "$Theurl" && printf '%s\n' "$Theurl" >> "$History" )
    printf '%s\n' "Remember to remove the audio/video files as appropriate."
}

geto handles all the different sites that youtube-dl supports.

The second helper I use is similar except that it only uses the last
11 characters of the argument (only with youtube.com), which can be
useful when cutting is awkward, or the code has to be typed from, say,
an image.

function gy {
    local History="$HOME/.get-youtube-download-history"
    local Youtube="$HOME/Youtube"
    [ -z "$1" ] && printf '%s\n' "Usage: $FUNCNAME [-e] [--force] [-s] foo-9_bar-8
	gets the specified video from www.youtube.com into $Youtube
	Only the last 11 characters of the argument are used.
	If the file already exists (any .ext), it just continues.
	-e just echoes the command that would be used for downloading.
	--force overrides the check that prevents redownloading a file.
	-s use a different format appropriate for my.strathspey.org
	Downloads are logged in $History" >&2 && return 1
    [ ! -r "$History" ] && printf '%s\n' "$History not found!" >&2 && return 1
    [ ! -d "$Youtube" ] && printf '%s\n' "Destination directory $Youtube not found!" >&2 && return 1
    local Echoonly="" Forcing="" Programmecode=""
    while [ $# -gt 0 ] ; do
	case "$1" in
	    -e)
		Echoonly=echo
		;;
	    --force)
		Forcing=force
		;;
	    -s)
		Spey=spey
		;;
	    *)
		[ -n "$Programmecode" ] && printf '%s\n' "Too many operands" && return 1
		Programmecode="$1"
		;;
	esac
	shift
    done
    [ -z "$Programmecode" ] && printf '%s\n' "Missing operand" && return 1
    Programmecode="${Programmecode:0-11:11}"
    [ -z "$Programmecode" ] && printf '%s\n' "Operand too short" && return 1
    grep -q -e "$Programmecode" "$History"
    [ $? -eq 0 -a -z "$Forcing" ] && printf '%s\n' "$Programmecode already in download history - override with --force" && return 1
    local Theurl=http://www.youtube.com/watch?v="$Programmecode"
    [ "$Spey" = "spey" ] && Theurl=https://www.youtube.com/v/"$Programmecode"?version=3
    printf '%s\n' "youtube-dl $Theurl"
    [ -n "$Echoonly" ] && return 0
    ( cd "$Youtube" && youtube-dl -k "$Theurl" && printf '%s\n' "$Theurl" >> "$History" )
    printf '%s\n' "Remember to remove the audio/video files as appropriate."
}

gy developed from getradio which treats 8 character BBC programme
codes in a similar way for get_iplayer, but the latter maintains
its own history cache. However, downloaded files don't retain their
timestamp, so bbc-redate does that empirically:

function getradio {
    [ -z "$1" ] && printf '%s\n' "Usage:	$FUNCNAME p00hgjc5
	gets the specified programme from the BBC radio website.
	Only the last 8 characters of the argument are used." >&2 && return 1
    local Programmecode="${1:0-8:8}"
    shift
    "$HOME"/bin/get_iplayer --pid "$Programmecode" --type radio --radiomode=worst,worse,good,vgood,better,best,daf,haf,hlsaac "$@"
    printf '%s\n' *"$Programmecode"* | tee /dev/stderr | wc -l | grep -q -e 1
    if [ $? -eq 0 ] ; then
	bbc-redate *"$Programmecode"*
    else
	printf '%s\n' "Too many files!" >&2
    fi
}

bbc-redate looks in each file for an occurrence of the pattern:
[12][0-9][0-9][0-9]-[01][0-9]-[0-3][0-9]T[012][0-9]:[0-5][0-9]:[0-5][0-9]

Make of it all what you will.

Cheers,
David.

[toc] | [prev] | [next] | [standalone]


#206417

Fromrhkramer@gmail.com
Date2019-03-21 03:20 +0100
Message-ID<xDVtf-4uV-1@gated-at.bofh.it>
In reply to#206415
Thanks!

On Wednesday, March 20, 2019 08:22:35 PM David Wright wrote:
> On Wed 20 Mar 2019 at 15:00:12 (-0400), rhkramer@gmail.com wrote:
> > Are you willing to share?
> 
> Sure. geto(thers) is what gy-in-quotes calls:
> 
> function geto {

[toc] | [prev] | [next] | [standalone]


#206401

FromPierre Frenkiel <pierre.frenkiel@gmail.com>
Date2019-03-20 19:20 +0100
Message-ID<xDNYJ-8eO-7@gated-at.bofh.it>
In reply to#206392
On Wed, 20 Mar 2019, Greg Wooledge wrote:

> On Wed, Mar 20, 2019 at 10:34:42AM +0100, Pierre Frenkiel wrote:
>> On Tue, 19 Mar 2019, riveravaldez wrote:
>>
>>> Maybe worth mentioning: youtube-dl, exceptionally useful and simple CLI tool.
>>
>>   useful and simple... but it works only for urls with alphanumeric characters
>>   I tried with an url containing ? and &, and I got nothing
>
> You probably forgot to quote the URL in your shell command.  If you don't
> quote it, the & is special to the shell and will cause the command to
> be split at that point, with the first half being run as a background
> command, and the second half being run as a foreground command.
>
>>   I tried also by escaping ? and & with \, and it was not better.
>>   I'll send you an example later, if you are not convinced...
>
> That should work.  An example of the failure would be helpful.
>
> Generally speaking, though, just wrap the whole URL in single quotes
> and you should be fine.
>
  Greg,
  I don't really understand your mail:
  in the 1st part, you tell me to quote the URL
  in the 2nd one, you seem aware that I actually did that
  BTW, escaping with \ or quoting the whole URL with '
  gives the same thing
  I'll send later the history of all my tries.

[toc] | [prev] | [next] | [standalone]


#206412

FromCelejar <celejar@gmail.com>
Date2019-03-20 23:20 +0100
Message-ID<xDRJ0-2b2-7@gated-at.bofh.it>
In reply to#206387
On Wed, 20 Mar 2019 10:34:42 +0100 (CET)
Pierre Frenkiel <pierre.frenkiel@gmail.com> wrote:

> On Tue, 19 Mar 2019, riveravaldez wrote:
> 
> > Maybe worth mentioning: youtube-dl, exceptionally useful and simple CLI tool.
> 
>    useful and simple... but it works only for urls with alphanumeric characters
>    I tried with an url containing ? and &, and I got nothing
>    I tried also by escaping ? and & with \, and it was not better.
>    I'll send you an example later, if you are not convinced...

You can also try putting the url(s) in a file, and feeding the file to
youtube-dl via its -a option.

Celejar

[toc] | [prev] | [next] | [standalone]


#206424

FromPierre Frenkiel <pierre.frenkiel@gmail.com>
Date2019-03-21 15:40 +0100
Message-ID<xE71n-3cP-9@gated-at.bofh.it>
In reply to#206412
On Wed, 20 Mar 2019, Celejar wrote:

> On Wed, 20 Mar 2019 10:34:42 +0100 (CET)
> Pierre Frenkiel <pierre.frenkiel@gmail.com> wrote:
>
>> On Tue, 19 Mar 2019, riveravaldez wrote:
>>
>>> Maybe worth mentioning: youtube-dl, exceptionally useful and simple CLI tool.
>>
>>    useful and simple... but it works only for urls with alphanumeric characters
>>    I tried with an url containing ? and &, and I got nothing
>>    I tried also by escaping ? and & with \, and it was not better.
>>    I'll send you an example later, if you are not convinced...
>
> You can also try putting the url(s) in a file, and feeding the file to
> youtube-dl via its -a option.
>
> Celejar
>

   At last, I fixed everything just by loadind the last version of youtube-dl from the
   yt-dl site
       wget https://yt-dl.org/latest/youtube-dl -O /usr/local/bin/youtube-dl

after that,  I can do either
     youtube-dl --no-playlist  'https://www.youtube.com/watch?v=VQd1IOyhKS4&list=RDEMlHFFKeq-aYlBhg-LtJ-SHw&start_radio=1'
     or
    youtube-dl https://www.youtube.com/watch?v=VQd1IOyhKS4 
both give exactly the same result.

My question is why the Debian version so obsolte ans uneliable?


best regards,
-- 
Pierre Frenkiel

[toc] | [prev] | [next] | [standalone]


#206427

FromDavid Wright <deblis@lionunicorn.co.uk>
Date2019-03-21 16:50 +0100
Message-ID<xE877-3Py-1@gated-at.bofh.it>
In reply to#206424
On Thu 21 Mar 2019 at 15:38:41 (+0100), Pierre Frenkiel wrote:
> On Wed, 20 Mar 2019, Celejar wrote:
> > On Wed, 20 Mar 2019 10:34:42 +0100 (CET) Pierre Frenkiel <pierre.frenkiel@gmail.com> wrote:
> > > On Tue, 19 Mar 2019, riveravaldez wrote:
> > > 
> > > > Maybe worth mentioning: youtube-dl, exceptionally useful and simple CLI tool.
> > > 
> > >    useful and simple... but it works only for urls with alphanumeric characters
> > >    I tried with an url containing ? and &, and I got nothing
> > >    I tried also by escaping ? and & with \, and it was not better.
> > >    I'll send you an example later, if you are not convinced...
> > 
> > You can also try putting the url(s) in a file, and feeding the file to
> > youtube-dl via its -a option.
> > 
> > Celejar
> > 
> 
>   At last, I fixed everything just by loadind the last version of youtube-dl from the
>   yt-dl site
>       wget https://yt-dl.org/latest/youtube-dl -O /usr/local/bin/youtube-dl
> 
> after that,  I can do either
>     youtube-dl --no-playlist  'https://www.youtube.com/watch?v=VQd1IOyhKS4&list=RDEMlHFFKeq-aYlBhg-LtJ-SHw&start_radio=1'
>     or
>    youtube-dl https://www.youtube.com/watch?v=VQd1IOyhKS4 both give
> exactly the same result.
> 
> My question is why the Debian version so obsolte ans uneliable?

The latest version on the website is three days old. The version I
installed from backports on Jan 28 was 11 days old.

You have to understand that sites like youtube and the BBC can
obsolete youtube-dl and get_iplayer overnight, and they do.
Then some clever people come up with a fix and release a new
version, and I heave a big sigh of relief and thanks. (Most
BBC programmes expire after four weeks, and I'm usually two or
three weeks behind, so a quick fix is vital.)

Debian mainstream doesn't work to that timetable, so you should
check out the backports, where those sorts of package appear.
Fortunately, get_iplayer is a single Perl script so I just
download it from its site and put it in ~/bin, as you can see
from my examples.

Cheers,
David.

[toc] | [prev] | [next] | [standalone]


#206433

FromFred <fred@blakemfg.com>
Date2019-03-21 18:40 +0100
Message-ID<xE9Pz-4Uw-5@gated-at.bofh.it>
In reply to#206427
On 03/21/2019 08:41 AM, David Wright wrote:
> On Thu 21 Mar 2019 at 15:38:41 (+0100), Pierre Frenkiel wrote:
>> On Wed, 20 Mar 2019, Celejar wrote:
>>> On Wed, 20 Mar 2019 10:34:42 +0100 (CET) Pierre Frenkiel <pierre.frenkiel@gmail.com> wrote:
>>>> On Tue, 19 Mar 2019, riveravaldez wrote:
>>>>
>>>>> Maybe worth mentioning: youtube-dl, exceptionally useful and simple CLI tool.
>>>>     useful and simple... but it works only for urls with alphanumeric characters
>>>>     I tried with an url containing ? and &, and I got nothing
>>>>     I tried also by escaping ? and & with \, and it was not better.
>>>>     I'll send you an example later, if you are not convinced...
>>> You can also try putting the url(s) in a file, and feeding the file to
>>> youtube-dl via its -a option.
>>>
>>> Celejar
>>>
>>    At last, I fixed everything just by loadind the last version of youtube-dl from the
>>    yt-dl site
>>        wget https://yt-dl.org/latest/youtube-dl -O /usr/local/bin/youtube-dl
>>
>> after that,  I can do either
>>      youtube-dl --no-playlist  'https://www.youtube.com/watch?v=VQd1IOyhKS4&list=RDEMlHFFKeq-aYlBhg-LtJ-SHw&start_radio=1'
>>      or
>>     youtube-dl https://www.youtube.com/watch?v=VQd1IOyhKS4 both give
>> exactly the same result.
>>
>> My question is why the Debian version so obsolte ans uneliable?
> The latest version on the website is three days old. The version I
> installed from backports on Jan 28 was 11 days old.
>
> You have to understand that sites like youtube and the BBC can
> obsolete youtube-dl and get_iplayer overnight, and they do.
> Then some clever people come up with a fix and release a new
> version, and I heave a big sigh of relief and thanks. (Most
> BBC programmes expire after four weeks, and I'm usually two or
> three weeks behind, so a quick fix is vital.)
>
> Debian mainstream doesn't work to that timetable, so you should
> check out the backports, where those sorts of package appear.
> Fortunately, get_iplayer is a single Perl script so I just
> download it from its site and put it in ~/bin, as you can see
> from my examples.
>
> Cheers,
> David.
>
>
Hi,
I think you would be better off with:

youtube-dl --update

also:

  youtube-dl --help

will show all the options.

Best regards,
Fred

[toc] | [prev] | [next] | [standalone]


Page 1 of 2  [1] 2  Next page →

Back to top | Article view | linux.debian.user


csiph-web